@@ -63,6 +63,10 @@ final class EncoderTest extends TestCase
 
     public function testChooseMode() : void
     {
+        // Empty string
+        $this->assertSame(Mode::BYTE(), $this->methods['chooseMode']->invoke(null, ''));
+        $this->assertSame(Mode::BYTE(), $this->methods['chooseMode']->invoke(null, '', 'SHIFT-JIS'));
+
         // Numeric mode
         $this->assertSame(Mode::NUMERIC(), $this->methods['chooseMode']->invoke(null, '0'));
         $this->assertSame(Mode::NUMERIC(), $this->methods['chooseMode']->invoke(null, '0123456789'));
@@ -77,7 +81,6 @@ final class EncoderTest extends TestCase
         // 8-bit byte mode
         $this->assertSame(Mode::BYTE(), $this->methods['chooseMode']->invoke(null, 'a'));
         $this->assertSame(Mode::BYTE(), $this->methods['chooseMode']->invoke(null, '#'));
-        $this->assertSame(Mode::BYTE(), $this->methods['chooseMode']->invoke(null, ''));
 
         // AIUE in Hiragana in SHIFT-JIS
         $this->assertSame(Mode::BYTE(), $this->methods['chooseMode']->invoke(null, "\x8\xa\x8\xa\x8\xa\x8\xa6"));
@@ -87,6 +90,12 @@ final class EncoderTest extends TestCase
 
         // Sou-Utso-Byou in Kanji in SHIFT-JIS
         $this->assertSame(Mode::BYTE(), $this->methods['chooseMode']->invoke(null, "\xe\x4\x9\x5\x9\x61"));
+
+        // SHIFT-JIS encoding, content only consists of double-byte kanji characters
+        $this->assertSame(Mode::KANJI(), $this->methods['chooseMode']->invoke(null, 'あいうえお', 'SHIFT-JIS'));
+
+        // SHIFT-JIS encoding, but content doesn't exclusively consist of kanji characters
+        $this->assertSame(Mode::BYTE(), $this->methods['chooseMode']->invoke(null, 'あいうえお123', 'SHIFT-JIS'));
     }
 
     public function testEncode() : void
